import React, { ComponentPropsWithoutRef } from 'react';
import { Orientation } from '../../../@types';
export interface IRadioGroupOption {
    description: string | React.ReactNode;
    disabled?: boolean;
    label: string | React.ReactNode;
    value: string | number;
    iconName?: string;
}
export interface IRadioGroupProps extends ComponentPropsWithoutRef<'input'> {
    /**
     * Defines disabled state
     */
    disabled?: boolean;
    /**
     * Defines label for SR-Only
     */
    label?: string;
    /**
     * Defines onChange event handler function
     */
    onChange: (value: any) => void;
    /**
     * Defines className for options wrapper element.
     */
    optionClassName?: string;
    /**
     * Defines className for options content element.
     */
    optionContentClassName?: string;
    /**
     * Defines options list
     */
    options: IRadioGroupOption[];
    /**
     * Defines Orientation. i.e "horizontal" or "vertical"
     */
    orientation?: keyof typeof Orientation;
    /**
     * Defines whether to show Radio element in left side or not.
     */
    showRadioLeft?: boolean;
    /**
     * Defines whether to show Radio element in right side or not.
     */
    showRadioRight?: boolean;
    /**
     * Defines whether to show Radio icon in left side or not.
     */
    showIconLeft?: boolean;
    /**
     * Defines whether to show Radio icon in right side or not.
     */
    showIconRight?: boolean;
    /**
     * Defines selected item value
     */
    value: any;
}
export interface IRadioGroupOptionProps extends ComponentPropsWithoutRef<'option'> {
    index: number;
    option: IRadioGroupOption;
    showRadioLeft?: boolean;
    showRadioRight?: boolean;
    showIconLeft?: boolean;
    showIconRight?: boolean;
    contentClassName: string;
}
declare const RadioGroup: React.ForwardRefExoticComponent<IRadioGroupProps & React.RefAttributes<HTMLInputElement>>;
export declare const RadioGroupOption: ({ className, index, option, showRadioLeft, showRadioRight, showIconLeft, showIconRight, contentClassName, }: IRadioGroupOptionProps) => JSX.Element;
export default RadioGroup;
//# sourceMappingURL=RadioGroup.d.ts.map